src/hotspot/share/classfile/classLoader.cpp
changeset 51444 3e5d28e6de32
parent 50962 dbe8aa90d4dd
child 52076 f8626bcc1698
--- a/src/hotspot/share/classfile/classLoader.cpp	Mon Aug 20 10:04:00 2018 +0200
+++ b/src/hotspot/share/classfile/classLoader.cpp	Mon Aug 20 08:25:57 2018 -0400
@@ -1400,7 +1400,7 @@
                                                            name,
                                                            loader_data,
                                                            protection_domain,
-                                                           NULL, // host_klass
+                                                           NULL, // unsafe_anonymous_host
                                                            NULL, // cp_patches
                                                            THREAD);
   if (HAS_PENDING_EXCEPTION) {
@@ -1443,8 +1443,8 @@
   assert(DumpSharedSpaces, "sanity");
   assert(stream != NULL, "sanity");
 
-  if (ik->is_anonymous()) {
-    // We do not archive anonymous classes.
+  if (ik->is_unsafe_anonymous()) {
+    // We do not archive unsafe anonymous classes.
     return;
   }